// Copyright (C) 2020-2023 David Sugar, Tycho Softworks
// This code is licensed under MIT license

#ifndef NETWORK_HPP_
#define NETWORK_HPP_

#include "compiler.hpp"

#include <string>
#include <cstdint>

#include <sys/socket.h>

struct sockaddr;
namespace server::net {
auto hostname() -> std::string;
auto to_string(const std::string& address, int port = 0) -> std::string;
auto if_address(const std::string& iface) -> std::string;
auto to_address(const std::string& name) -> std::string;
void fqdn(std::string& host);
auto size(const struct sockaddr *addr) -> socklen_t;

auto uri_schema(const std::string& id) -> std::string;
auto uri_userid(const std::string& id) -> std::string;
auto uri_server(const std::string& id) -> std::string;
auto uri_port(const std::string& id) -> uint16_t;
auto uri_host(const std::string& id) -> std::string;
auto uri_address(const std::string& id) -> std::string;

auto set_user(const std::string& uri, const std::string& user) -> std::string;
auto make_uri(const std::string& schema, const std::string& host, uint16_t port = 0) -> std::string;
auto make_uri(const std::string& schema, const std::string& user, const std::string& host, uint16_t port = 0) -> std::string;

auto bind(const char *media, uint16_t mport = 0) -> std::pair<int, uint16_t>;
auto store(struct sockaddr_storage& addr, const std::string& host, uint16_t port = 0) -> bool;
} // end namespaces...

/*!
 * Common network utility functions.
 * \file network.hpp
 */
#endif
