// Copyright (C) 2020-2023 David Sugar, Tycho Softworks
// This code is licensed under MIT license

#ifndef UTILS_HPP_
#define UTILS_HPP_

#include "compiler.hpp"

#include <list>
#include <string>
#include <cstdint>

namespace server {
void logger(const std::string& msg);
void log_reset();
} // end namespace server

namespace server::util {
auto u8verify(const char *cp, size_t max = 255) -> size_t;
auto compare(std::string_view from, std::string_view to) -> bool;
auto get_env(const char *id, size_t max = FILENAME_MAX) -> const char *;
auto get_value(std::string_view text) -> int;
auto get_duration(const char *cp, long scale = 1000L) -> long;
auto set_priority(int priority) -> bool;
auto to_b64(const uint8_t *data, size_t size) -> std::string;
} // end namespace server utils

/*!
 * Utility functions and support for the server.
 * \file utils.hpp
 */
#endif
